@@ -49,6 +49,10 @@ func (r *Request) AuthorizeRequest(
 		r.Form.Set("scope", strings.Join(cconfig.Scopes, " "))
 	}
 
+	if len(cconfig.ACRValues) > 0 {
+		r.Form.Set("acr_values", strings.Join(cconfig.ACRValues, " "))
+	}
+
 	if len(cconfig.Audience) > 0 {
 		r.Form.Set("audience", strings.Join(cconfig.Audience, " "))
 	}
@@ -121,6 +125,10 @@ func (r *Request) AuthorizeRequest(
 			r.Form.Set("scope", strings.Join(cconfig.Scopes, " "))
 		}
 
+		if len(cconfig.ACRValues) > 0 {
+			r.Form.Set("acr_values", strings.Join(cconfig.ACRValues, " "))
+		}
+
 		if len(cconfig.Audience) > 0 {
 			r.Form.Set("audience", strings.Join(cconfig.Audience, " "))
 		}
